<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2009 Olivier Meunier and contributors
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------
if (!defined('DC_CONTEXT_ADMIN')) { return; }

$m_object = $m_title = $m_url = null;
$wave_page = !empty($_POST['wave_page']) ? $_POST['wave_page'] : null;
$services_regs = array( 'wave' =>		'#^https://wave.google.com/wave/(.+)#'
);
// https://wave.google.com/wave/?pli=1#restored:wave:googlewave.com!w%252BoeJRwxygA

if ($wave_page)
{
	try
	{
		$media_service = false;
		foreach ($services_regs as $k => $v) {
			if (preg_match($v,$wave_page)) {
				$media_service = $k;
				break;
			}
		}
		
		if (!$media_service) {
			throw new Exception(__('Unsupported service'));
		}
		
		switch ($media_service)
		{
			case 'wave':
				if (preg_match('#wave:googlewave.com!w%252B(.+?)(&|$)#',$wave_page,$waveID))
				{
					$m_object = $waveID[1];
				} else {
					$m_object = '<p> &lt;div&gt; gWave not created: cannot parse URL.</p>'."\n";
				}
				$m_url = $wave_page;
				break;
		}
	}
	catch (Exception $e)
	{
		$core->error->add($e->getMessage());
	}
}
?>
<html>
<head>
  <title><?php echo __('Google Wave toolbox') ?></title>
  <?php echo dcPage::jsLoad('index.php?pf=googleWave/js/popup.js'); ?>
  <?php echo dcPage::jsColorPicker(); ?>
</head>

<body>
<?php
echo '<h2>'.__('Google Wave toolbox').'</h2>';

if (!$m_object)
{
	echo
	'<form action="'.$p_url.'&amp;popup=1" method="post">'.
	'<p>'.__('Please enter the URL of the page containing the wave you want to include in your post.').'</p>'.
	'<p><label>'.__('Page URL:').' '.
	form::field('wave_page',50,250,html::escapeHTML($wave_page)).'</label></p>'.
	
	'<p><input type="submit" value="'.__('ok').'" />'.
	$core->formNonce().'</p>'.
	'</form>';
}
else
{
	$waveID = $m_object;

	/* Prevualisation */
	echo
	'<div style="margin: 1em auto; padding : 0.2em; border : 2px solid black;'.
	'text-align: center;background : white; color : black;">'."\n".
	'<p>&lt;div class="wave" id="'.$waveID.'" '.
	'style="<span id="w_style"></span>"&gt;&lt;/div&gt;</p>'.
	'</div>'.
	'<form id="media-insert-form" action="" method="get">';
	
	/* Default values */
	$core->blog->settings->setNamespace('googlewave');
	$m_bg = $core->blog->settings->background;
	$m_fg = $core->blog->settings->foreground;
	$m_font = $core->blog->settings->font;
	$m_font_size = $core->blog->settings->font_size;
	$m_width = $core->blog->settings->width;
	$m_height = $core->blog->settings->height;
	$m_alignment = $core->blog->settings->alignment;
	$m_server = $core->blog->settings->server;
	$m_fName = $core->blog->settings->fName;
	$core->blog->settings->setNamespace('sytem');

	/* fields */
	echo '<h3>'.__('Server settings').'</h3>'."\n".
		'<p class="field"><label>'.__('Wave Server').' '.
		form::field('m_server',50,180,$m_server).
		'</label></p>'.
		'<p><label class="classic">'.__('Wave formatted name').
		form::field('m_fName',20,50,$m_fName).
		'<em>waveID</em></label></p>'.
		'<p class="field"><label>'.__('Wave ID').
		form::field('m_object',20,50,$m_object).
		'</label></p>';

	$i_align = array(
		'none' => array(__('None'),0),
		'left' => array(__('Left'),0),
		'right' => array(__('Right'),0),
		'center' => array(__('Center'),0)
	);
	$i_align[$m_alignment][1] = 1;
	echo '<h3>'.__('Media alignment').'</h3>';
	echo '<p>';
	foreach ($i_align as $k => $v) {
		echo '<label class="classic">'.
		form::radio(array('alignment'),$k,$v[1]).' '.$v[0].'</label><br /> ';
	}
	echo '</p>';
	
	echo '<h3>'.__('Box dimension').'</h3>'.
	'<p class="field"><label>'.__('Width:').' '.
	form::field('m_width',14,14,html::escapeHTML($m_width), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Height:').' '.
	form::field('m_height',14,14,html::escapeHTML($m_height), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>';

	echo '<h3>'.__('Other appearance setting').'</h3>'.
	'<p class="field"><label>'.__('Background color:').' '.
	form::field('m_bg',14,14,html::escapeHTML($m_bg),'colorpicker',
	'', false, 'onchange="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Text color:').' '.
	form::field('m_fg',14,14,html::escapeHTML($m_fg),'colorpicker', 
	'', false, 'onchange="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Default font:').' '.
	form::field('m_font',14,14,html::escapeHTML($m_font), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Default font size:').' '.
	form::field('m_font_size',14,14,html::escapeHTML($m_font_size), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>';
	
	echo
	'<h3>'.__('Media title').'</h3>'.
	'<p class="field"><label>'.__('Title:').' '.
	form::field('m_title',50,150,html::escapeHTML($m_title)).'</label></p>';
	echo 
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		"$('#m_title').focus()".
		"\n//]]>\n".
		"</script>\n";
	
	echo
	'<p><a id="media-insert-cancel" class="button" href="#">'.__('Cancel').'</a> - '.
	'<strong><a id="media-insert-ok" class="button" href="#">'.__('Insert').'</a></strong>'.
	form::hidden('m_url',html::escapeHTML($m_url)).
	'</p>'.
	'<p>'.$core->formNonce().'</p>'.
	'</form>';
}
?>
</body>
</html>
